netapp_ontap.models.nfs_service_protocol_v40_features API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nfs_service_protocol_v40_features`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NfsServiceProtocolV40FeaturesSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NfsServiceProtocolV40Features object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `acl_enabled GET POST PATCH`

    Specifies whether NFSv4.0 ACLs is enabled.

  `read_delegation_enabled GET POST PATCH`

    Specifies whether NFSv4.0 Read Delegation is enabled.

  `write_delegation_enabled GET POST PATCH`

    Specifies whether NFSv4.0 Write Delegation is enabled.